@@ -9,7 +9,10 @@
 
 // KF
 #include <KPluginFactory>
+#include <kparts_version.h>
+#if KPARTS_VERSION < QT_VERSION_CHECK(5, 77, 0)
 #include <KAboutData>
+#endif
 
 
 class MarkdownPartFactory : public KPluginFactory
@@ -27,8 +30,10 @@ public:
                     QWidget* parentWidget, QObject* parent,
                     const QVariantList& args, const QString& keyword) override;
 
+#if KPARTS_VERSION < QT_VERSION_CHECK(5, 77, 0)
 private:
     KAboutData m_aboutData;
+#endif
 };
 
 #endif
